# DMSalesAPI
[![Upload Python Package](https://github.com/DBMS-dev/DMSalesAPI/actions/workflows/python-publish.yml/badge.svg)](https://github.com/DBMS-dev/DMSalesAPI/actions/workflows/python-publish.yml)

Python library implementing DMSales API methods

[Official API Documentation](https://app.dmsales.com/api-doc/default)

## Use case

You can copy and paste some code from [examples file](https://github.com/DBMS-dev/DMSalesAPI/blob/main/examples/basic_operations.py), to see how it works.

## Tests

To run unit tests, you should run command:
```
python -m pytest tests
```
